@@ -1,12 +1,12 @@
 cv.lognet <-
-  function (outlist, lambda, x, y, weights, offset, foldid, type.measure, 
-            grouped, keep = FALSE) 
+  function (outlist, lambda, x, y, weights, offset, foldid, type.measure,
+            grouped, keep = FALSE)
 {
-  typenames = c(mse = "Mean-Squared Error", mae = "Mean Absolute Error", 
+  typenames = c(mse = "Mean-Squared Error", mae = "Mean Absolute Error",
     deviance = "Binomial Deviance", auc = "AUC", class = "Misclassification Error")
-  if (type.measure == "default") 
+  if (type.measure == "default")
     type.measure = "deviance"
-  if (!match(type.measure, c("mse", "mae", "deviance", "auc", 
+  if (!match(type.measure, c("mse", "mae", "deviance", "auc",
                              "class"), FALSE)) {
     warning("Only 'deviance', 'class', 'auc', 'mse' or 'mae'  available for binomial models; 'deviance' used")
     type.measure = "deviance"
@@ -23,12 +23,12 @@ cv.lognet <-
   N = nrow(y)
   nfolds = max(foldid)
   if ((N/nfolds < 10) && type.measure == "auc") {
-    warning("Too few (< 10) observations per fold for type.measure='auc' in cv.lognet; changed to type.measure='deviance'. Alternatively, use smaller value for nfolds", 
+    warning("Too few (< 10) observations per fold for type.measure='auc' in cv.lognet; changed to type.measure='deviance'. Alternatively, use smaller value for nfolds",
             call. = FALSE)
     type.measure = "deviance"
   }
   if ((N/nfolds < 3) && grouped) {
-    warning("Option grouped=FALSE enforced in cv.glmnet, since < 3 observations per fold", 
+    warning("Option grouped=FALSE enforced in cv.glmnet, since < 3 observations per fold",
             call. = FALSE)
     grouped = FALSE
   }
@@ -45,9 +45,9 @@ cv.lognet <-
   for (i in seq(nfolds)) {
     which = foldid == i
     fitobj = outlist[[i]]
-    if (is.offset) 
+    if (is.offset)
       off_sub = offset[which]
-    preds = predict(fitobj,x[which, , drop = FALSE], s=lambda[which_lam], offset = off_sub, 
+    preds = predict(fitobj,x[which, , drop = FALSE], s=lambda[which_lam], newoffset = off_sub,
       type = "response")
     nlami = sum(which_lam)
     predmat[which, seq(nlami)] = preds
@@ -60,7 +60,7 @@ cv.lognet <-
       good[i, seq(nlams[i])] = 1
       which = foldid == i
       for (j in seq(nlams[i])) {
-        cvraw[i, j] = auc.mat(y[which, ], predmat[which, 
+        cvraw[i, j] = auc.mat(y[which, ], predmat[which,
                j], weights[which])
       }
     }
@@ -72,8 +72,8 @@ cv.lognet <-
     y = y/ywt
     weights = weights * ywt
     N = nrow(y) - apply(is.na(predmat), 2, sum)
-    cvraw = switch(type.measure, mse = (y[, 1] - (1 - predmat))^2 + 
-      (y[, 2] - predmat)^2, mae = abs(y[, 1] - (1 - predmat)) + 
+    cvraw = switch(type.measure, mse = (y[, 1] - (1 - predmat))^2 +
+      (y[, 2] - predmat)^2, mae = abs(y[, 1] - (1 - predmat)) +
       abs(y[, 2] - predmat), deviance = {
         predmat = pmin(pmax(predmat, prob_min), prob_max)
         lp = y[, 1] * log(1 - predmat) + y[, 2] * log(predmat)
@@ -81,7 +81,7 @@ cv.lognet <-
         ly[y == 0] = 0
         ly = drop((y * ly) %*% c(1, 1))
         2 * (ly - lp)
-      }, class = y[, 1] * (predmat > 0.5) + y[, 2] * (predmat <= 
+      }, class = y[, 1] * (predmat > 0.5) + y[, 2] * (predmat <=
            0.5))
     if (grouped) {
       cvob = cvcompute(cvraw, weights, foldid, nlams)
@@ -91,10 +91,10 @@ cv.lognet <-
     }
   }
   cvm = apply(cvraw, 2, weighted.mean, w = weights, na.rm = TRUE)
-  cvsd = sqrt(apply(scale(cvraw, cvm, FALSE)^2, 2, weighted.mean, 
+  cvsd = sqrt(apply(scale(cvraw, cvm, FALSE)^2, 2, weighted.mean,
     w = weights, na.rm = TRUE)/(N - 1))
   out = list(cvm = cvm, cvsd = cvsd, name = typenames[type.measure])
-  if (keep) 
+  if (keep)
     out$fit.preval = predmat
   out
 }
